@@ -47,7 +47,7 @@ pref("keyword.URL", "http://keyword.netscape.com/keyword/");
 pref("keyword.enabled", false);
 pref("general.useragent.locale", "chrome://navigator/locale/navigator.properties");
 pref("general.useragent.contentlocale", "chrome://navigator-region/locale/region.properties");
-pref("general.useragent.misc", "rv:1.3b");
+pref("general.useragent.misc", "rv:1.3.1");
 
 pref("general.startup.browser",             true);
 pref("general.startup.mail",                false);
@@ -230,6 +230,10 @@ pref("browser.fixup.alternate.enabled", true);
 pref("browser.fixup.alternate.prefix", "www.");
 pref("browser.fixup.alternate.suffix", ".com");
 
+// Default bookmark sorting
+pref("browser.bookmarks.sort.direction", "descending");
+pref("browser.bookmarks.sort.resource", "rdf:http://home.netscape.com/NC-rdf#Name");
+
 //Internet Search
 pref("browser.search.defaultenginename", "chrome://communicator-region/locale/region.properties");
 
@@ -276,7 +280,7 @@ pref("print.print_edge_bottom", 0); // 1/100 of an inch
 // Editing these may create a security risk - be sure you know what you're doing
 //pref("capability.policy.default.barprop.visible.set", "UniversalBrowserWrite");
 
-pref("capability.policy.default_policynames", "mailnews");
+pref("capability.policy.default_policynames", "mailnews allowclipboard");
 pref("capability.policy.policynames", "");
 
 pref("capability.policy.default.DOMException.code", "allAccess");
@@ -425,6 +429,12 @@ pref("capability.policy.mailnews.SchemaLoader.onError", "noAccess");
 pref("capability.policy.default.XMLHttpRequest.channel", "noAccess");
 pref("capability.policy.default.DOMParser.parseFromStream", "noAccess");
 
+// Clipboard
+pref("capability.policy.default.Clipboard.cutcopy", "noAccess");
+pref("capability.policy.default.Clipboard.paste", "noAccess");
+pref("capability.policy.allowclipboard.sites", "http://www.mozilla.org");
+pref("capability.policy.allowclipboard.Clipboard.cutcopy", "allAccess");
+pref("capability.policy.allowclipboard.Clipboard.paste", "allAccess");
 
 // Scripts & Windows prefs
 pref("browser.block.target_new_window",     false);
@@ -837,6 +847,6 @@ pref("browser.popups.showPopupBlocker", true);
 // See http://bugzilla.mozilla.org/show_bug.cgi?id=169483 for further details...
 pref("viewmanager.do_doublebuffering", true);
 
-pref("privacy.popups.sound_enabled",              true);
+pref("privacy.popups.sound_enabled",              false);
 pref("privacy.popups.sound_url",                  "");
 pref("privacy.popups.statusbar_icon_enabled",     true);
